bayespy.nodes.Multinomial
=========================

.. currentmodule:: bayespy.nodes

.. autoclass:: Multinomial

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Multinomial.__init__
      ~Multinomial.add_plate_axis
      ~Multinomial.broadcasting_multiplier
      ~Multinomial.delete
      ~Multinomial.get_gradient
      ~Multinomial.get_mask
      ~Multinomial.get_moments
      ~Multinomial.get_parameters
      ~Multinomial.get_riemannian_gradient
      ~Multinomial.get_shape
      ~Multinomial.has_plotter
      ~Multinomial.initialize_from_parameters
      ~Multinomial.initialize_from_prior
      ~Multinomial.initialize_from_random
      ~Multinomial.initialize_from_value
      ~Multinomial.load
      ~Multinomial.logpdf
      ~Multinomial.lower_bound_contribution
      ~Multinomial.lowerbound
      ~Multinomial.move_plates
      ~Multinomial.observe
      ~Multinomial.pdf
      ~Multinomial.plot
      ~Multinomial.random
      ~Multinomial.save
      ~Multinomial.set_parameters
      ~Multinomial.set_plotter
      ~Multinomial.show
      ~Multinomial.unobserve
      ~Multinomial.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Multinomial.dims
      ~Multinomial.plates
      ~Multinomial.plates_multiplier
   
   